health library

Classes

ActivityIntensityHealthValue
Represents a period of moderate or vigorous activity intensity on Android.
AudiogramHealthValue
A HealthValue object for audiograms
ElectrocardiogramHealthValue
A HealthValue object for ECGs
ElectrocardiogramVoltageValue
Single voltage value belonging to a ElectrocardiogramHealthValue
Health
Main class for the Plugin.
HealthChange
HealthChangesResponse
HealthDataPoint
A HealthDataPoint object corresponds to a data point capture from Apple HealthKit or Google Health Connect with a HealthValue as value.
HealthValue
An abstract class for health values.
InsulinDeliveryHealthValue
A HealthValue object from insulin delivery (iOS only)
MenstruationFlowHealthValue
A HealthValue object for menstrual flow.
NumericHealthValue
A numerical value from Apple HealthKit or Google Health Connect such as integer or double. E.g. 1, 2.9, -3
NutritionHealthValue
A HealthValue object for nutrition.
SkinTemperatureHealthValue
Represents a skin temperature delta sample on Android.
WorkoutHealthValue
A HealthValue object for workouts
WorkoutRouteHealthValue
Route data captured for a workout session.
WorkoutRouteLocation
A single location sample captured as part of a workout route.
WorkoutSummary
A WorkoutSummary object store vary metrics of a workout.

Enums

ActivityIntensityLevel
ElectrocardiogramClassification
Classifications for ECG readings.
HealthChangeType
HealthConnectSdkStatus
The status of Google Health Connect.
HealthDataAccess
Access types for Health Data.
HealthDataType
List of all available health data types.
HealthDataUnit
List of all HealthDataUnits.
HealthPlatformType
Types of health platforms.
HealthWorkoutActivityType
List of HealthWorkoutActivityTypes.
InsulinDeliveryReason
Types of insulin delivery reason
MealType
MenstrualFlow
RecordingMethod
SkinTemperatureMeasurementLocation
The measurement location for a skin temperature record on Android.

Constants

dataTypeKeysAndroid → const List<HealthDataType>
List of data types available on Android
dataTypeKeysIOS → const List<HealthDataType>
List of data types available on iOS.
dataTypeToUnit → const Map<HealthDataType, HealthDataUnit>
Maps a HealthDataType to a HealthDataUnit.

Exceptions / Errors

HealthException
Custom Exception for the plugin. Used when a Health Data Type is requested, but not available on the current platform.